# MOMORING #

A simple, graceful tool for developer

### Installation ###
`pip install MOMORING`

### Usage ###
`momo init -p your_project_name`
`momo test -p your_project_path`

### Maintainer ###
wenzhi.ma@xtalpi.com
